!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define("buildbot-ws-keepalive-plugin",[],t):"object"==typeof exports?exports["buildbot-ws-keepalive-plugin"]=t():e["buildbot-ws-keepalive-plugin"]=t()}("undefined"!=typeof self?self:this,(function(){return function(e){var t={};function n(o){if(t[o])return t[o].exports;var r=t[o]={i:o,l:!1,exports:{}};return e[o].call(r.exports,r,r.exports,n),r.l=!0,r.exports}return n.m=e,n.c=t,n.d=function(e,t,o){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:o})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var o=Object.create(null);if(n.r(o),Object.defineProperty(o,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)n.d(o,r,function(t){return e[t]}.bind(null,r));return o},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=0)}([function(e,t,n){n(1),n(2);angular.module("ws_keepalive_plugin").run(["$interval","socketService",class WsKeepAlive{constructor(e,t){e((function(){t.send({msg:"keepalive"})}),3e4)}}])},function(e,t){angular.module("ws_keepalive_plugin",[]).config(["$stateProvider",class WsKeepaliveState{constructor(e){e.state({controller:"WsKeepaliveController",name:"WsKeepaliveState",data:{}})}}])},function(e,t){angular.module("ws_keepalive_plugin").controller("WsKeepaliveController",[class WsKeepaliveController{constructor(){}}])}])}));
//# sourceMappingURL=scripts.js.map